@@ -2,7 +2,7 @@ from .higherLevelAPI import *
 import itertools
 from .dataCleaning import *
 from .taxonomyAPI import *
-import grequests
+from requests import Session
 
 def commonNameAPI(bestEffortsOnSpecies):
     noWorkResults = []
@@ -11,8 +11,8 @@ def commonNameAPI(bestEffortsOnSpecies):
         if len(speciesResult) > 0: noWorkResults.append((name,True,speciesResult))
         else: toProcess.append(name)
     urls = list(map(constructUrls,toProcess))
-    reqs = (grequests.get(url) for url in urls)
-    results = grequests.map(reqs,size=10)
+    session = Session()
+    results = list(map(lambda x: session.get(x),urls))
     results = safeMapResToJson(results)
     results = list(zip(toProcess,results))
     results = list(map(processIndividualResult,results))
