@@ -1,4 +1,4 @@
-import grequests
+from requests import Session
 from .dataCleaning import *
 
 def higherLevelAPI(originalNamesWithTaxa):
@@ -10,8 +10,8 @@ def higherLevelAPI(originalNamesWithTaxa):
         elif taxaDetails[0] == 'species': noWorkResults.append((name,True,[cleanSingleSpeciesString(taxaDetails[1])]))
         else: toProcess.append((name,taxaDetails))
     urls = list(map(constructUrls,toProcess))
-    reqs = (grequests.get(url) for url in urls)
-    results = grequests.map(reqs,size=10)
+    session = Session()
+    results = list(map(lambda x: session.get(x),urls))
     results = safeMapResToJson(results)
     results = list(zip(toProcess,results))
     results = list(map(processIndividualResult,results))
